==> xlockmore-5.06.tar.bz2: xlockmore-5.06/language.ja.tcl <==
# -*-tcl-*-
#
# Japanese language file for gettext.tcl
#
# By: YOKOTA Hiroshi <yokota@netlab.is.tsukuba.ac.jp>

# $Id: language.ja.tcl,v 1.3 2000/07/31 03:36:52 elca Exp $

settext "Wizard configure" "configure "
settext "Font Options" "ե ץ"

#settext "OK"        "OK"
settext "Configure" "Configure ¹"
settext "Abort"     ""

settext "Make"         "make ¹"
settext "Make Install" "make install ¹"
settext "Exit"         "λ"
settext "Go back"      ""

settext "Do you really want to launch configure?" "configure ¹ԤƤǤ?"
settext "Launch Configure" "configure ¹"

settext -Adobe-Courier-Bold-R-Normal-*-140-* -*-fixed-medium-r-normal-*-14-*-*-*-*-*-*-*

settext "File"  "ե"
settext "Color" ""
settext "Font"  "ե"

#settext "ABCDEFGHIJKabedfghijkmnopq12345" "ABCDEFGHIJKabedfghijkmnopq12345"

settext "wizard configure xlockmore" "xlockmore configure "
settext "This should help you to build xlockmore" "Υɤ xlockmore ιۤñ˽ޤ"

settext "without gcc    " "gcc     Ȥʤ"
settext "with-purify    " "purify  Ȥ    "
settext "without motif  " "Motif   Ȥʤ"
settext "without editres" "editres Ȥʤ"
settext "without xpm    " "Xpm     Ȥʤ"
settext "without opengl " "OpenGL  Ȥʤ"
settext "without mesagl " "MesaGL  Ȥʤ"
settext "without dtsaver" "dtsaver Ȥʤ"
settext "without dpms   " "dpms    Ȥʤ"

settext "Wizard configure image path" "Υѥ"
settext "please enter the image path" "ξϤƲ"

settext "Bitmap dir"                  "ӥåȥޥåפΥǥ쥯ȥ"
settext "Pixmaps dir"                 "ԥޥåפΥǥ쥯ȥ"
settext "sound player program"        "ѤΥץ̾  "
settext "enable syslog logging      " "syslog ǥ                  "
settext "enable multiple users      " "ʣͤƱå             "
settext "enable multiple root users " "root ޤʣͤƱå"
settext "enable unstable            " "ȯΥ⡼ɤȤ                 "

settext "Wizard configure include and library path" "󥯥롼ɥեȥ饤֥Υѥ"
settext "Please enter the path" "ѥ̾ϤƲ"

settext "path of X include          " "X Υ󥯥롼ɥեѥ      "
settext "path of X library          " "X Υ饤֥ѥ                "
settext "user executables in        " "桼ѥץ।󥹥ȡ"
settext "system admin executables in" "ѥץ।󥹥ȡ"
settext "program executables in     " "ץ।󥹥ȡ    "
settext "info documentation in      " "Info ɥȥ󥹥ȡ "
settext "man documentation in       " "ޥ˥奢륤󥹥ȡ        "
settext "find the sources in        " "¸߰              "

settext "Wizard configure language" ""
settext "Please choice your language " "Ѥǲ"

settext "Dutch   " ""
settext "English " "Ѹ      "
settext "French  " "ʩ      "
settext "German  " "ȸ      "
settext "Japanese" "ܸ    "

settext "< Previous" " "
settext "Next >"     " "

# end

==> xlockmore-5.11.1.tar.bz2: xlockmore-5.11.1/language.ja.tcl <==
# -*-tcl-*-
#
# Japanese language file for gettext.tcl
#
# By: YOKOTA Hiroshi <yokota@netlab.is.tsukuba.ac.jp>

# $Id: language.ja.tcl,v 1.3 2000/07/31 03:36:52 elca Exp $

settext "Wizard configure" "configure "
settext "Font Options" "ե ץ"

#settext "OK"        "OK"
settext "Configure" "Configure ¹"
settext "Abort"     ""

settext "Make"         "make ¹"
settext "Make Install" "make install ¹"
settext "Exit"         "λ"
settext "Go back"      ""

settext "Do you really want to launch configure?" "configure ¹ԤƤǤ?"
settext "Launch Configure" "configure ¹"

settext -Adobe-Courier-Bold-R-Normal-*-140-* -*-fixed-medium-r-normal-*-14-*-*-*-*-*-*-*

settext "File"  "ե"
settext "Color" ""
settext "Font"  "ե"

#settext "ABCDEFGHIJKabedfghijkmnopq12345" "ABCDEFGHIJKabedfghijkmnopq12345"

settext "wizard configure xlockmore" "xlockmore configure "
settext "This should help you to build xlockmore" "Υɤ xlockmore ιۤñ˽ޤ"

settext "without gcc    " "gcc     Ȥʤ"
settext "with-purify    " "purify  Ȥ    "
settext "without motif  " "Motif   Ȥʤ"
settext "without editres" "editres Ȥʤ"
settext "without xpm    " "Xpm     Ȥʤ"
settext "without opengl " "OpenGL  Ȥʤ"
settext "without mesa   " "Mesa    Ȥʤ"
settext "without dtsaver" "dtsaver Ȥʤ"
settext "without dpms   " "dpms    Ȥʤ"

settext "Wizard configure image path" "Υѥ"
settext "please enter the image path" "ξϤƲ"

settext "Bitmap dir"                  "ӥåȥޥåפΥǥ쥯ȥ"
settext "Pixmaps dir"                 "ԥޥåפΥǥ쥯ȥ"
settext "sound player program"        "ѤΥץ̾  "
settext "enable syslog logging      " "syslog ǥ                  "
settext "enable multiple users      " "ʣͤƱå             "
settext "enable multiple root users " "root ޤʣͤƱå"
settext "enable unstable            " "ȯΥ⡼ɤȤ                 "

settext "Wizard configure include and library path" "󥯥롼ɥեȥ饤֥Υѥ"
settext "Please enter the path" "ѥ̾ϤƲ"

settext "path of X include          " "X Υ󥯥롼ɥեѥ      "
settext "path of X library          " "X Υ饤֥ѥ                "
settext "user executables in        " "桼ѥץ।󥹥ȡ"
settext "system admin executables in" "ѥץ।󥹥ȡ"
settext "program executables in     " "ץ।󥹥ȡ    "
settext "info documentation in      " "Info ɥȥ󥹥ȡ "
settext "man documentation in       " "ޥ˥奢륤󥹥ȡ        "
settext "find the sources in        " "¸߰              "

settext "Wizard configure language" ""
settext "Please choice your language " "Ѥǲ"

settext "Dutch   " ""
settext "English " "Ѹ      "
settext "French  " "ʩ      "
settext "German  " "ȸ      "
settext "Japanese" "ܸ    "

settext "< Previous" " "
settext "Next >"     " "

# end
